@@ -1,6 +1,6 @@
-from __future__ import division
+import logging
 import os
-import sys
+from shutil import which
 import subprocess
 from platform import system as _current_os
 import re
@@ -48,6 +48,29 @@ class CommandRunner:
         self.dry = dry
         self.output = None
 
+    @staticmethod
+    def prune_ffmpeg_progress_from_output(output: str) -> str:
+        return "\n".join(
+            [
+                line
+                for line in output.splitlines()
+                if not any(
+                    key in line
+                    for key in [
+                        "bitrate=",
+                        "total_size=",
+                        "out_time_us=",
+                        "out_time_ms=",
+                        "out_time=",
+                        "dup_frames=",
+                        "drop_frames=",
+                        "speed=",
+                        "progress=",
+                    ]
+                )
+            ]
+        )
+
     def run_ffmpeg_command(self):
         # wrapper for 'ffmpeg-progress-yield'
         logger.debug(f"Running command: {self.cmd}")
@@ -56,7 +79,11 @@ class CommandRunner:
             yield progress
 
         self.output = ff.stderr
-        logger.debug(f"ffmpeg output: {self.output}")
+
+        if logger.getEffectiveLevel() == logging.DEBUG:
+            logger.debug(
+                f"ffmpeg output: {CommandRunner.prune_ffmpeg_progress_from_output(self.output)}"
+            )
 
     def run_command(self):
         logger.debug(f"Running command: {self.cmd}")
@@ -82,43 +109,12 @@ class CommandRunner:
         if p.returncode == 0:
             self.output = stdout + stderr
         else:
-            raise RuntimeError(
-                f"Error running command {self.cmd}: {str(stderr)}"
-            )
+            raise RuntimeError(f"Error running command {self.cmd}: {str(stderr)}")
 
     def get_output(self):
         return self.output
 
 
-def which(program):
-    """
-    Find a program in PATH and return path
-    From: http://stackoverflow.com/q/377017/
-    """
-
-    def is_exe(fpath):
-        found = os.path.isfile(fpath) and os.access(fpath, os.X_OK)
-        if not found and sys.platform == "win32":
-            fpath = fpath + ".exe"
-            found = os.path.isfile(fpath) and os.access(fpath, os.X_OK)
-        return found
-
-    fpath, _ = os.path.split(program)
-    if fpath:
-        if is_exe(program):
-            logger.debug("found executable: " + str(program))
-            return program
-    else:
-        for path in os.environ["PATH"].split(os.pathsep):
-            path = os.path.expandvars(os.path.expanduser(path)).strip('"')
-            exe_file = os.path.join(path, program)
-            if is_exe(exe_file):
-                logger.debug("found executable in path: " + str(exe_file))
-                return exe_file
-
-    return None
-
-
 def dict_to_filter_opts(opts):
     filter_opts = []
     for k, v in opts.items():
