@@ -14,6 +14,7 @@ NORMALIZATION_TYPES = ["ebu", "rms", "peak"]
 PCM_INCOMPATIBLE_FORMATS = ["mp4", "mp3", "ogg", "webm"]
 PCM_INCOMPATIBLE_EXTS = ["mp4", "m4a", "mp3", "ogg", "webm"]
 
+
 def check_range(number, min_r, max_r, name=""):
     """
     Check if a number is within a given range
@@ -21,9 +22,7 @@ def check_range(number, min_r, max_r, name=""):
     try:
         number = float(number)
         if number < min_r or number > max_r:
-            raise FFmpegNormalizeError(
-                f"{name} must be within [{min_r},{max_r}]"
-            )
+            raise FFmpegNormalizeError(f"{name} must be within [{min_r},{max_r}]")
         return number
         pass
     except Exception as e:
@@ -42,9 +41,11 @@ class FFmpegNormalize:
         print_stats=False,
         # threshold=0.5,
         loudness_range_target=7.0,
+        keep_loudness_range_target=False,
         true_peak=-2.0,
         offset=0.0,
         dual_mono=False,
+        dynamic=False,
         audio_codec="pcm_s16le",
         audio_bitrate=None,
         sample_rate=None,
@@ -83,12 +84,15 @@ class FFmpegNormalize:
         # self.threshold = float(threshold)
 
         self.loudness_range_target = check_range(
-            loudness_range_target, 1, 20, name="loudness_range_target"
+            loudness_range_target, 1, 50, name="loudness_range_target"
         )
+
+        self.keep_loudness_range_target = keep_loudness_range_target
         self.true_peak = check_range(true_peak, -9, 0, name="true_peak")
         self.offset = check_range(offset, -99, 99, name="offset")
 
         self.dual_mono = True if dual_mono in ["true", True] else False
+        self.dynamic = True if dynamic in ["true", True] else False
         self.audio_codec = audio_codec
         self.audio_bitrate = audio_bitrate
         self.sample_rate = int(sample_rate) if sample_rate is not None else None
@@ -159,8 +163,8 @@ class FFmpegNormalize:
             self.audio_codec is None or "pcm" in self.audio_codec
         ) and ext in PCM_INCOMPATIBLE_EXTS:
             raise FFmpegNormalizeError(
-                f"Output extension {ext} does not support PCM audio. " +
-                "Please choose a suitable audio codec with the -c:a option."
+                f"Output extension {ext} does not support PCM audio. "
+                + "Please choose a suitable audio codec with the -c:a option."
             )
 
         mf = MediaFile(self, input_file, output_file)
